==> polls-v1.4.1.zip: polls/messages/ar/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>ملاحظة:</strong> يتم إخفاء النتيجة حتى يتم إغلاق الاستطلاع بواسطة المشرف.',
    'Access denied!' => 'تم منع الوصول!',
    'Add answer...' => 'إضافة إجابة',
    'Again? ;Weary;' => 'مرة أخرى؟ ؛المرهق؛',
    'Allows the user to create polls' => 'السماح للمستخدم بإنشاء استطلاعات الرأي',
    'Allows to start polls.' => 'السماح ببدء الاستطلاعات.',
    'Anonymous' => 'مجهول',
    'Anonymous Votes?' => 'أصوات مجهولة؟',
    'Anonymous poll!' => 'استطلاع كمجهول!',
    'Answers' => 'الإجابات',
    'At least one answer is required' => 'مطلوب إجابة واحدة على الأقل',
    'Cancel' => 'إلغاء',
    'Close Poll' => 'إكمال الاستطلاع',
    'Closed' => 'مغلق',
    'Club A Steakhouse' => 'نادي ستيك هاوس',
    'Could not load poll!' => 'فشل تحميل الاستطلاع!',
    'Create poll' => 'إنشاء استطلاع',
    'Description' => 'الوصف',
    'Display answers in random order?' => 'عرض الإجابات بترتيب عشوائي؟',
    'Edit answer (empty answers will be removed)...' => 'تحرير الإجابة (الإجابة الفارغة سيتم حذفها)...',
    'Edit your poll question...' => 'تحرير سؤال استطلاعك',
    'Hide results until poll is closed?' => 'إخفاء النتائج حتى يغلق التصويت؟',
    'Invalid answer!' => 'إجابة غير صالحة!',
    'Location of the next meeting' => 'مكان اللقاء القادم',
    'Multiple answers per user' => 'إجابات متعددة لكل مستخدم',
    'Pisillo Italian Panini' => 'بانيني إيطالي صغير',
    'Please specify at least {min} answers!' => 'يرجى تحديد {min} من الإجابات على الأقل!',
    'Poll' => 'استطلاع',
    'Polls' => 'الاستطلاعات',
    'Question' => 'سؤال',
    'Reopen Poll' => 'إعادة فتح الاستطلاع',
    'Reset my vote' => 'إعادة تعيين تصويتي',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'نحن الآن في مراحل التخطيط للقائنا القادم ونود أن نعرف منك، إلى أين تريد أن تذهب؟',
    'Save' => 'حفظ',
    'To Daniel' => 'إلى دانيال',
    'Users voted for: <strong>{answer}</strong>' => 'صوّت المستخدمون لـ: <strong>{answer}</strong>',
    'Vote' => 'التصويت',
    'Voting for multiple answers is disabled!' => 'تم تعطيل التصويت لإجابات متعددة!',
    'Whenever someone participates in a poll.' => 'عندما يشارك شخص ما في استطلاع رأي.',
    'Why don\'t we go to Bemelmans Bar?' => 'لماذا لا نذهب إلى  Bemelmans?',
    'You have insufficient permissions to perform that operation!' => 'ليس لديك الأذونات الكافية لتنفيذ هذه العملية!',
    'and {count} more vote for this.' => 'و{count} المزيد من الأصوات لهذا.',
    'votes' => 'أصوات',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}صوت{htmlTagEnd}}other{# {htmlTagBegin}أصوات{htmlTagEnd}}}',
    '{userName} answered the {question}.' => 'أجاب {userName} على {question}.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/ar/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>ملاحظة:</strong> يتم إخفاء النتيجة حتى يتم إغلاق الاستطلاع بواسطة المشرف.',
    'Access denied!' => 'تم منع الوصول!',
    'Add answer...' => 'إضافة إجابة',
    'Again? :weary:' => 'مرة أخرى؟ ؛المرهق؛',
    'Allows the user to create polls' => 'السماح للمستخدم بإنشاء استطلاعات الرأي',
    'Allows to start polls.' => 'السماح ببدء الاستطلاعات.',
    'Anonymous' => 'مجهول',
    'Anonymous Votes?' => 'أصوات مجهولة؟',
    'Anonymous poll!' => 'استطلاع كمجهول!',
    'Answers' => 'الإجابات',
    'At least one answer is required' => 'مطلوب إجابة واحدة على الأقل',
    'Cancel' => 'إلغاء',
    'Close Poll' => 'إكمال الاستطلاع',
    'Closed' => 'مغلق',
    'Club A Steakhouse' => 'نادي ستيك هاوس',
    'Could not load poll!' => 'فشل تحميل الاستطلاع!',
    'Create poll' => 'إنشاء استطلاع',
    'Description' => 'الوصف',
    'Display answers in random order?' => 'عرض الإجابات بترتيب عشوائي؟',
    'Edit answer (empty answers will be removed)...' => 'تحرير الإجابة (الإجابة الفارغة سيتم حذفها)...',
    'Edit your poll question...' => 'تحرير سؤال استطلاعك',
    'Hide results until poll is closed?' => 'إخفاء النتائج حتى يغلق التصويت؟',
    'Invalid answer!' => 'إجابة غير صالحة!',
    'Location of the next meeting' => 'مكان اللقاء القادم',
    'Multiple answers per user' => 'إجابات متعددة لكل مستخدم',
    'Pisillo Italian Panini' => 'بانيني إيطالي صغير',
    'Please specify at least {min} answers!' => 'يرجى تحديد {min} من الإجابات على الأقل!',
    'Poll' => 'استطلاع',
    'Polls' => 'الاستطلاعات',
    'Question' => 'سؤال',
    'Reopen Poll' => 'إعادة فتح الاستطلاع',
    'Reset my vote' => 'إعادة تعيين تصويتي',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'نحن الآن في مراحل التخطيط للقائنا القادم ونود أن نعرف منك، إلى أين تريد أن تذهب؟',
    'Save' => 'حفظ',
    'To Daniel' => 'إلى دانيال',
    'Users voted for: <strong>{answer}</strong>' => 'صوّت المستخدمون لـ: <strong>{answer}</strong>',
    'Vote' => 'التصويت',
    'Voting for multiple answers is disabled!' => 'تم تعطيل التصويت لإجابات متعددة!',
    'Whenever someone participates in a poll.' => 'عندما يشارك شخص ما في استطلاع رأي.',
    'Why don\'t we go to Bemelmans Bar?' => 'لماذا لا نذهب إلى  Bemelmans?',
    'You have insufficient permissions to perform that operation!' => 'ليس لديك الأذونات الكافية لتنفيذ هذه العملية!',
    'and {count} more vote for this.' => 'و{count} المزيد من الأصوات لهذا.',
    'votes' => 'أصوات',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}صوت{htmlTagEnd}}other{# {htmlTagBegin}أصوات{htmlTagEnd}}}',
    '{userName} answered the {question}.' => 'أجاب {userName} على {question}.',
    'Poll content ID' => '',
];
